/*=============================================================================
Vitalnix User Management Suite
drivers/proto.h
  Copyright © Jan Engelhardt <jengelh [at] gmx de>, 2005 - 2006
  -- License restrictions apply (LGPL v2.1)

  This file is part of Vitalnix.
  Vitalnix is free software; you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published
  by the Free Software Foundation; however ONLY version 2 of the License.

  Vitalnix is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this program kit; if not, write to:
  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  Boston, MA  02110-1301  USA

  -- For details, see the file named "LICENSE.LGPL2"
=============================================================================*/
#ifndef _VITALNIX_DRIVERS_PROTO_H
#define _VITALNIX_DRIVERS_PROTO_H 1

#define DRIVER_PROTO(name) \
    static int name##_init(struct vxpdb_state *, const void *); \
    static int name##_open(struct vxpdb_state *, long); \
    static void name##_close(struct vxpdb_state *); \
    static void name##_deinit(struct vxpdb_state *); \
    static long name##_modctl(struct vxpdb_state *, long, ...); \
    static int name##_lock(struct vxpdb_state *); \
    static int name##_unlock(struct vxpdb_state *); \
    \
    static int name##_useradd(struct vxpdb_state *, const struct vxpdb_user *); \
    static int name##_usermod(struct vxpdb_state *, const struct vxpdb_user *, const struct vxpdb_user *); \
    static int name##_userdel(struct vxpdb_state *, const struct vxpdb_user *); \
    static int name##_userinfo(struct vxpdb_state *, const struct vxpdb_user *, struct vxpdb_user *, size_t); \
    static void *name##_usertrav_init(struct vxpdb_state *); \
    static int name##_usertrav_walk(struct vxpdb_state *, void *, struct vxpdb_user *); \
    static void name##_usertrav_free(struct vxpdb_state *, void *); \
    \
    static int name##_groupadd(struct vxpdb_state *, const struct vxpdb_group *); \
    static int name##_groupmod(struct vxpdb_state *, const struct vxpdb_group *, const struct vxpdb_group *); \
    static int name##_groupdel(struct vxpdb_state *, const struct vxpdb_group *); \
    static int name##_groupinfo(struct vxpdb_state *, const struct vxpdb_group *, struct vxpdb_group *, size_t); \
    static void *name##_grouptrav_init(struct vxpdb_state *); \
    static int name##_grouptrav_walk(struct vxpdb_state *, void *, struct vxpdb_group *); \
    static void name##_grouptrav_free(struct vxpdb_state *, void *);

#define DRIVER_CB(name) \
    .init           = name##_init, \
    .open           = name##_open, \
    .close          = name##_close, \
    .deinit         = name##_deinit, \
    .modctl         = name##_modctl, \
    .lock           = name##_lock, \
    .unlock         = name##_unlock, \
    \
    .useradd        = name##_useradd, \
    .usermod        = name##_usermod, \
    .userdel        = name##_userdel, \
    .userinfo       = name##_userinfo, \
    .usertrav_init  = name##_usertrav_init, \
    .usertrav_walk  = name##_usertrav_walk, \
    .usertrav_free  = name##_usertrav_free, \
    \
    .groupadd       = name##_groupadd, \
    .groupmod       = name##_groupmod, \
    .groupdel       = name##_groupdel, \
    .groupinfo      = name##_groupinfo, \
    .grouptrav_init = name##_grouptrav_init, \
    .grouptrav_walk = name##_grouptrav_walk, \
    .grouptrav_free = name##_grouptrav_free

#endif // _VITALNIX_DRIVERS_PROTO_H

//=============================================================================
